front

package
v0.3.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 14, 2026 License: MIT Imports: 5 Imported by: 3

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Input

func Input(prompt string) string

Input prompts the user for input and returns the input as a string.

func InputBinary

func InputBinary(prompt string) bool

InputBinary prompts the user with a yes/no question and returns the response as a boolean.

func InputInt

func InputInt(prompt string, min, max int) int

InputInt prompts the user for input and returns the input as an integer. A negative min/max value will disable the respective limit.

func InputMenuGen

func InputMenuGen(prompt string, options []string) int

InputMenuGen prompts the user with a menu and returns the user's choice as an integer.

func InputSecret added in v0.3.0

func InputSecret(prompt string) []byte

InputSecret prompts the user for input and returns the input as a byte array, hiding the input from the terminal.

Types

This section is empty.

Jump to