Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func InputBinary ¶
InputBinary prompts the user with a yes/no question and returns the response as a boolean.
func InputInt ¶
InputInt prompts the user for input and returns the input as an integer. A negative min/max value will disable the respective limit.
func InputMenuGen ¶
InputMenuGen prompts the user with a menu and returns the user's choice as an integer.
func InputSecret ¶ added in v0.3.0
InputSecret prompts the user for input and returns the input as a byte array, hiding the input from the terminal.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.